==> apeman-task-apstyle-1.0.5.tgz: package/lib/define.js <==
/**
 * apeman task to render React ApStyle element as a css file.
 * @memberof module:apeman-task-apstyle/lib
 * @function define
 * @param {string} src - React style source file.
 * @param {string} dest - Destination file name.
 * @param {object} [options] - Optional settings.
 * @param {string} [options.mode='644'] - File permission mode.
 * @param {string} [options.props={}] - Properties to render.
 * @returns {function} - Defined task function.
 */

"use strict";

const argx = require('argx'),
    React = require('react'),
    async = require('async'),
    ReactDOM = require('react-dom/server'),
    path = require('path'),
    os = require('os'),
    findout = require('findout'),
    cssbeautify = require('cssbeautify'),
    _comment = require('./_comment'),
    xml2js = require('xml2js'),
    writeout = require('writeout'),
    pkg = require('../package.json'),
    objnest = require('objnest');

/** @lends define */
function define(src, dest, options) {
    let args = argx(arguments);
    options = objnest.expand(args.pop('object') || {});

    let mode = options.mode || '644';

    let props = options.props;

    /**
     * Defined task.
     * @function task
     * @param {object} context - Apeman task context.
     * @param {function} callback - Callback when done.
     */
    function task(context, callback) {
        let logger = context.logger,
            verbose = context.verbose;
        let originalSrc = src;

        if (typeof(src) === 'string') {
            src = findout(src, {safe: true});
        }

        if (!src) {
            logger.warn(`[${pkg.name}] src not found: ${originalSrc}`);
            callback(null);
            return;
        }

        let element = React.createElement(src, props);

        let html = ReactDOM.renderToStaticMarkup(element);

        async.waterfall([
            (callback) => {
                xml2js.parseString(html, callback);
            },
            (data, callback) => {
                let css = [
                    _comment(dest, src),
                    cssbeautify(data.style._)
                ].join(os.EOL);
                writeout(dest, css, {
                    skipIfIdentical: true,
                    mkdirp: true,
                    mode: mode
                }, (err, result) => {
                    let generated = !err && !result.skipped;
                    if (generated) {
                        console.log(`File generated: ${result.filename}`);
                    }
                    callback(err);
                });
            }
        ], callback);
    }

    // Description of this task.
    task.$desc = "Render react ap-style component.";
    return task;
}

module.exports = define;

==> apeman-task-apstyle-1.1.1.tgz: package/lib/define.js <==
/**
 * apeman task to render React ApStyle element as a css file.
 * @memberof module:apeman-task-apstyle/lib
 * @function define
 * @param {string} src - React style source file.
 * @param {string} dest - Destination file name.
 * @param {object} [options] - Optional settings.
 * @param {string} [options.mode='644'] - File permission mode.
 * @param {string} [options.props={}] - Properties to render.
 * @returns {function} - Defined task function.
 */

"use strict";

const argx = require('argx'),
    React = require('react'),
    async = require('async'),
    ReactDOM = require('react-dom/server'),
    path = require('path'),
    os = require('os'),
    findout = require('findout'),
    cssbeautify = require('cssbeautify'),
    _comment = require('./_comment'),
    xml2js = require('xml2js'),
    writeout = require('writeout'),
    pkg = require('../package.json'),
    objnest = require('objnest');

/** @lends define */
function define(src, dest, options) {
    let args = argx(arguments);
    options = objnest.expand(args.pop('object') || {});

    let mode = options.mode || '644';

    let props = options.props;

    /**
     * Defined task.
     * @function task
     * @param {object} context - Apeman task context.
     * @param {function} callback - Callback when done.
     */
    function task(context, callback) {
        let logger = context.logger,
            verbose = context.verbose;

        let Component = src;

        if (typeof(Component) === 'string') {
            Component = findout(Component, {safe: true});
        }

        if (!Component) {
            logger.warn(`[${pkg.name}] src not found: ${src}`);
            callback(null);
            return;
        }

        let element = React.createElement(Component.default || Component, props);

        let html = ReactDOM.renderToStaticMarkup(element);

        async.waterfall([
            (callback) => {
                xml2js.parseString(html, callback);
            },
            (data, callback) => {
                let style = data.style;
                if (!style) {
                    callback(new Error('Failed to parse style with html: ' + html));
                    return;
                }
                let css = [
                    _comment(dest, src),
                    cssbeautify(style._)
                ].join(os.EOL);
                writeout(dest, css, {
                    skipIfIdentical: true,
                    mkdirp: true,
                    mode: mode
                }, (err, result) => {
                    let generated = !err && !result.skipped;
                    if (generated) {
                        console.log(`File generated: ${result.filename}`);
                    }
                    callback(err);
                });
            }
        ], callback);
    }

    // Description of this task.
    task.$desc = "Render react ap-style component.";
    return task;
}

module.exports = define;
